import { RawSplitChunksOptions } from "@rspack/binding";
/**
 * Options object for splitting chunks into smaller chunks.
 */
export interface OptimizationSplitChunksOptions {
    /**
     * Sets the name delimiter for created chunks.
     */
    /**
     * Assign modules to a cache group (modules from different cache groups are tried to keep in separate chunks, default categories: 'default', 'defaultVendors').
     */
    cacheGroups?: {
        /**
         * Configuration for a cache group.
         */
        [k: string]: OptimizationSplitChunksCacheGroup;
    };
    /**
     * Select chunks for determining shared modules (defaults to "async", "initial" and "all" requires adding these chunks to the HTML).
     */
    chunks?: "initial" | "async" | "all";
    /**
     * Sets the size types which are used when a number is used for sizes.
     */
    /**
     * Size threshold at which splitting is enforced and other restrictions (minRemainingSize, maxAsyncRequests, maxInitialRequests) are ignored.
     */
    enforceSizeThreshold?: OptimizationSplitChunksSizes;
    /**
     * Options for modules not selected by any other cache group.
     */
    /**
     * Sets the template for the filename for created chunks.
     */
    /**
     * Prevents exposing path info when creating names for parts splitted by maxSize.
     */
    /**
     * Maximum number of requests which are accepted for on-demand loading.
     */
    maxAsyncRequests?: number;
    /**
     * Maximal size hint for the on-demand chunks.
     */
    maxAsyncSize?: OptimizationSplitChunksSizes;
    /**
     * Maximum number of initial chunks which are accepted for an entry point.
     */
    maxInitialRequests?: number;
    /**
     * Maximal size hint for the initial chunks.
     */
    maxInitialSize?: OptimizationSplitChunksSizes;
    /**
     * Maximal size hint for the created chunks.
     */
    maxSize?: OptimizationSplitChunksSizes;
    /**
     * Minimum number of times a module has to be duplicated until it's considered for splitting.
     */
    minChunks?: number;
    /**
     * Minimal size for the chunks the stay after moving the modules to a new chunk.
     */
    minRemainingSize?: OptimizationSplitChunksSizes;
    /**
     * Minimal size for the created chunks.
     */
    minSize?: OptimizationSplitChunksSizes;
    /**
     * Minimum size reduction due to the created chunk.
     */
    minSizeReduction?: OptimizationSplitChunksSizes;
    /**
     * Give chunks created a name (chunks with equal name are merged).
     */
    name?: false | string | Function;
}
/**
 * Options object for describing behavior of a cache group selecting modules that should be cached together.
 */
export interface OptimizationSplitChunksCacheGroup {
    /**
     * Sets the name delimiter for created chunks.
     */
    automaticNameDelimiter?: string;
    chunks?: "initial" | "async" | "all";
    enforce?: boolean;
    enforceSizeThreshold?: OptimizationSplitChunksSizes;
    filename?: string;
    idHint?: string;
    layer?: RegExp | string | Function;
    maxAsyncRequests?: number;
    maxAsyncSize?: OptimizationSplitChunksSizes;
    maxInitialRequests?: number;
    maxInitialSize?: OptimizationSplitChunksSizes;
    maxSize?: OptimizationSplitChunksSizes;
    minChunks?: number;
    minRemainingSize?: OptimizationSplitChunksSizes;
    minSize?: OptimizationSplitChunksSizes;
    minSizeReduction?: OptimizationSplitChunksSizes;
    name?: string;
    priority?: number;
    reuseExistingChunk?: boolean;
    test?: RegExp;
}
/**
 * Size description for limits.
 */
export declare type OptimizationSplitChunksSizes = number;
export declare function resolveSplitChunksOptions(op?: OptimizationSplitChunksOptions): undefined | RawSplitChunksOptions;
//# sourceMappingURL=splitChunks.d.ts.map